@@ -59,11 +59,16 @@ def test_model(config: dict, fun_control: dict) -> Tuple[float, float]:
     else:
         enable_progress_bar = fun_control["enable_progress_bar"]
     # Add "TEST" postfix to config_id
-    config_id = generate_config_id(config) + "_TEST"
+    # config id is unique. Since the model is loaded from a checkpoint,
+    # the config id is generated here without a timestamp. This differs from
+    # the config id generated in cvmodel.py and trainmodel.py.
+    config_id = generate_config_id(config, timestamp=False) + "_TEST"
     dm = LightDataModule(
         dataset=fun_control["data_set"],
         batch_size=config["batch_size"],
         num_workers=fun_control["num_workers"],
+        test_size=fun_control["test_size"],
+        test_seed=fun_control["test_seed"],
     )
     dm.setup()
     # Init model from datamodule's attributes
@@ -81,8 +86,8 @@ def test_model(config: dict, fun_control: dict) -> Tuple[float, float]:
         # Where to save models
         default_root_dir=os.path.join(fun_control["CHECKPOINT_PATH"], config_id),
         max_epochs=model.hparams.epochs,
-        accelerator="auto",
-        devices=1,
+        accelerator=fun_control["accelerator"],
+        devices=fun_control["devices"],
         logger=TensorBoardLogger(
             save_dir=fun_control["TENSORBOARD_PATH"], version=config_id, default_hp_metric=True, log_graph=True
         ),
