@@ -9,10 +9,13 @@ import os
 
 def load_data(data_dir="./data"):
     """Loads the CIFAR10 dataset.
+
     Args:
         data_dir (str, optional): Directory to save the data. Defaults to "./data".
+
     Returns:
         trainset (torchvision.datasets.CIFAR10): Training dataset.
+
     Examples:
         >>> from spotPython.utils.file import load_data
         >>> trainset = load_data(data_dir="./data")
@@ -29,10 +32,13 @@ def load_data(data_dir="./data"):
 
 def get_experiment_name(prefix: str = "00") -> str:
     """Returns a unique experiment name with a given prefix.
+
     Args:
         prefix (str, optional): Prefix for the experiment name. Defaults to "00".
+
     Returns:
         str: Unique experiment name.
+
     Examples:
         >>> from spotPython.utils.file import get_experiment_name
         >>> get_experiment_name(prefix="00")
@@ -48,9 +54,11 @@ def get_experiment_name(prefix: str = "00") -> str:
 def save_pickle(obj, filename: str):
     """Saves an object as a pickle file.
         Add .pkl to the filename.
+
     Args:
         obj (object): Object to be saved.
         filename (str): Name of the pickle file.
+
     Examples:
         >>> from spotPython.utils.file import save_pickle
         >>> save_pickle(obj, filename="obj.pkl")
@@ -63,10 +71,13 @@ def save_pickle(obj, filename: str):
 def load_pickle(filename: str):
     """Loads a pickle file.
         Add .pkl to the filename.
+
     Args:
         filename (str): Name of the pickle file.
+
     Returns:
         (object): Loaded object.
+
     Examples:
         >>> from spotPython.utils.file import load_pickle
         >>> obj = load_pickle(filename="obj.pkl")
@@ -79,8 +90,10 @@ def load_pickle(filename: str):
 
 def get_spot_tensorboard_path(experiment_name):
     """Get the path to the spot tensorboard files.
+
     Args:
         experiment_name (str): The name of the experiment.
+
     Returns:
         spot_tensorboard_path (str): The path to the folder where the spot tensorboard files are saved.
     """
@@ -91,9 +104,52 @@ def get_spot_tensorboard_path(experiment_name):
 
 def get_tensorboard_path(fun_control):
     """Get the path to the tensorboard files.
+
     Args:
         fun_control (dict): The function control dictionary.
+
     Returns:
         tensorboard_path (str): The path to the folder where the tensorboard files are saved.
     """
     return fun_control["TENSORBOARD_PATH"]
+
+
+def save_experiment(spot_tuner, fun_control) -> str:
+    """
+    Saves the experiment as a pickle file.
+
+    Args:
+        spot_tuner (object): The spot tuner object.
+        fun_control (dict): The function control dictionary.
+
+    Returns:
+        PKL_NAME (str):
+            Name of the pickle file. Build as "spot_" + PREFIX + "experiment.pickle".
+
+    """
+    experiment = {"spot_tuner": spot_tuner, "fun_control": fun_control}
+    PREFIX = fun_control["PREFIX"]
+    PKL_NAME = "spot_" + PREFIX + "experiment.pickle"
+    with open(PKL_NAME, "wb") as handle:
+        pickle.dump(experiment, handle, protocol=pickle.HIGHEST_PROTOCOL)
+    print(f"Experiment saved as {PKL_NAME}")
+    return PKL_NAME
+
+
+def load_experiment(PKL_NAME):
+    """
+    Loads the experiment from a pickle file.
+
+    Args:
+        PKL_NAME (str): Name of the pickle file.
+
+    Returns:
+        spot_tuner (object): The spot tuner object.
+        fun_control (dict): The function control dictionary.
+
+    """
+    with open(PKL_NAME, "rb") as handle:
+        experiment = pickle.load(handle)
+    spot_tuner = experiment["spot_tuner"]
+    fun_control = experiment["fun_control"]
+    return spot_tuner, fun_control
